<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Phunk
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function phunk_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	//Blog layout
	$blog_layout 	= phunk_blog_layout();
	if ( is_home() || is_archive() ) {
		$classes[] 		= esc_attr( $blog_layout );
	}

	return $classes;
}
add_filter( 'body_class', 'phunk_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function phunk_post_classes( $classes ) {

	if ( !is_single() ) {
		$classes[] = 'grid-item';
	}

	return $classes;
}
add_filter( 'post_class', 'phunk_post_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function phunk_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'phunk_pingback_header' );

/**
 * Get the first category of the post
 */
function phunk_first_category() {
	$categories = get_the_category();
	if ( ! empty( $categories ) ) {
	    echo '<a class="first-cat post-cat" href="' . esc_url( get_category_link( $categories[0]->term_id ) ) . '">' . esc_html( $categories[0]->name ) . '</a>';
	}
}

/**
 * Container type
 */
function phunk_container_type() {

	if ( is_singular() ) {
		$container = 'cont1200 contPadSmall';
	} else {
		$container = 'cont1600 contPad';
	}

	return $container;
}



if ( ! function_exists( 'phunk_post_navigation' ) ) :
	/**
	 * Display navigation to next/previous post when applicable.
	 *
	 */
	function phunk_post_navigation() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );
	
		if ( ! $next && ! $previous ) {
			return;
		}
	
		$prev_post = get_previous_post();
		if ($prev_post) {
			$prev_thumbnail = get_the_post_thumbnail($prev_post->ID, 'thumbnail' );
		} else {
			$prev_thumbnail = '';
		}
		$next_post = get_next_post();
		if ($next_post) {
			$next_thumbnail = get_the_post_thumbnail($next_post->ID, 'thumbnail' );
		} else {
			$next_thumbnail ='';
		}
		if ($prev_thumbnail) {
			$has_prev_thumb = 'has-thumb';
		} else {
			$has_prev_thumb = '';
		}
		if ($next_thumbnail) {
			$has_next_thumb = 'has-thumb';
		} else {
			$has_next_thumb = '';
		}

		$type = get_theme_mod( 'post_navigation', 'floating' );
	
		?>
		<nav class="navigation post-navigation <?php echo esc_attr( $type ); ?>" role="navigation">
			<h2 class="screen-reader-text"><?php _e( 'Post navigation', 'phunk' ); ?></h2>
			<div class="nav-links">
				<?php	
					if (get_previous_post()) {
					echo '<div class="nav-previous ' . $has_prev_thumb . '">';
						echo '<div class="post-nav-label">' . esc_html__( 'Previous post', 'phunk' ) . '</div>';
						if ($prev_thumbnail) {
							echo $prev_thumbnail;
						}
						previous_post_link( '%link', '<h3>%title</h3>' );
					echo '</div>';
					}
					if (get_next_post()) {
					echo '<div class="nav-next ' . $has_next_thumb . '">';
						echo '<div class="post-nav-label">' . esc_html__( 'Next post', 'phunk' ) . '</div>';
						next_post_link( '%link', '<h3>%title</h3>' );
						if ($next_thumbnail) {
							echo $next_thumbnail;
						}
					echo '</div>';
					}
				?>
			</div><!-- .nav-links -->
		</nav><!-- .navigation -->
		<?php
	}
endif;

if ( ! function_exists( 'phunk_site_identity' ) ) :
	/**
	 * Site identity
	 *
	 */
	function phunk_site_identity() {
		?>
		<header id="masthead" class="site-header">
			<div class="inner-header cont1600 contPad contCenter" style="background-image: url(<?php echo esc_url( get_header_image() ); ?>)">
				<div class="site-branding">
					<?php
					the_custom_logo();
					if ( is_front_page() && is_home() ) :
						?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php
					else :
						?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
					endif;
					$phunk_description = get_bloginfo( 'description', 'display' );
					if ( $phunk_description || is_customize_preview() ) :
						?>
						<p class="site-description"><?php echo $phunk_description; /* WPCS: xss ok. */ ?></p>
					<?php endif; ?>

					<?php
					//Social icons
					$socials = phunk_header_social();

					if ( $socials ) : ?>	

					<div class="header-social">
						<?php foreach( $socials as $social ) : ?>
							<div class="social-item"><a target="_blank" href="<?php echo esc_url( $social['link_url'] ); ?>"><i class="<?php echo esc_attr( $social['icon'] ); ?>"></i></a></div>
						<?php endforeach; ?>
					</div>		
					<?php endif; ?>

				</div><!-- .site-branding -->
			</div>		
		</header><!-- #masthead -->
		<?php
	}
endif;


if ( ! function_exists( 'phunk_hot_topics' ) ) :
	/**
	 * Hot topics
	 *
	 */
	function phunk_hot_topics() {

		$box_1_image = get_theme_mod( 'box_1_image' );
		$box_1_text  = get_theme_mod( 'box_1_text' );
		$box_1_url   = get_theme_mod( 'box_1_url' );
		$box_2_image = get_theme_mod( 'box_2_image' );
		$box_2_text  = get_theme_mod( 'box_2_text' );
		$box_2_url   = get_theme_mod( 'box_2_url' );
		$box_3_image = get_theme_mod( 'box_3_image' );
		$box_3_text  = get_theme_mod( 'box_3_text' );
		$box_3_url   = get_theme_mod( 'box_3_url' );
		$box_4_image = get_theme_mod( 'box_4_image' );
		$box_4_text  = get_theme_mod( 'box_4_text' );
		$box_4_url   = get_theme_mod( 'box_4_url' );

		if ( '' == $box_1_image ) {
			return;
		}

		if ( is_home() ) : ?>
		<div id="hot-topics" class="hot-topics clear">
			<div class="cont1600 contPad contCenter">
				<?php if ( $box_1_image ) : ?>
				<div class="hot-item">
					<div class="hot-item-inner" style="background-image: url( <?php echo esc_url( $box_1_image ); ?> );">
						<span><a href="<?php echo esc_html( $box_1_url ); ?>"><?php echo esc_html( $box_1_text ); ?></a></span>
					</div>
				</div>	
				<?php endif; ?>
				<?php if ( $box_2_image ) : ?>
				<div class="hot-item">
					<div class="hot-item-inner" style="background-image: url( <?php echo esc_url( $box_2_image ); ?> );">
						<span><a href="<?php echo esc_html( $box_2_url ); ?>"><?php echo esc_html( $box_2_text ); ?></a></span>
					</div>
				</div>	
				<?php endif; ?>
				<?php if ( $box_3_image ) : ?>
				<div class="hot-item">
					<div class="hot-item-inner" style="background-image: url( <?php echo esc_url( $box_3_image ); ?> );">
						<span><a href="<?php echo esc_html( $box_3_url ); ?>"><?php echo esc_html( $box_3_text ); ?></a></span>
					</div>
				</div>		
				<?php endif; ?>
				<?php if ( $box_4_image ) : ?>
				<div class="hot-item">
					<div class="hot-item-inner" style="background-image: url( <?php echo esc_url( $box_4_image ); ?> );">
						<span><a href="<?php echo esc_html( $box_4_url ); ?>"><?php echo esc_html( $box_4_text ); ?></a></span>
					</div>
				</div>			
				<?php endif; ?>
			</div>
		</div>	
		<?php endif;
	}
endif;			


if ( ! function_exists( 'phunk_site_navigation' ) ) :
	/**
	 * Site navigation
	 *
	 */
	function phunk_site_navigation() {
		?>

		<header id="masthead" class="site-header">
			<div class="inner-header cont1600 contPad contCenter">
				<div class="site-branding col25">
					<?php

					if ( has_custom_logo() ) {
						the_custom_logo();
					} else {
						if ( is_front_page() && is_home() ) :
							?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php
						else :
							?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
						endif;
						$phunk_description = get_bloginfo( 'description', 'display' );
						if ( $phunk_description || is_customize_preview() ) :
							?>
							<p class="site-description"><?php echo $phunk_description; /* WPCS: xss ok. */ ?></p>
						<?php endif; ?>							
					<?php } ?>
				</div>

				<nav id="site-navigation" class="main-navigation col75">

					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i class="icon-menu"></i></button>
					
					<?php
					wp_nav_menu( array(
						'theme_location' => 'menu-1',
						'menu_id'        => 'primary-menu',
					) );
					?>
				</nav><!-- #site-navigation -->


			</div>
		</header>
		<?php
	}
endif;		

if ( ! function_exists( 'phunk_top_bar' ) ) :
	/**
	 * Top bar
	 *
	 */
	function phunk_top_bar() {
		
		$socials = get_theme_mod( 'header_social' );
		?>

		<div class="top-bar">
			<div class="inner-top-bar cont1600 contPad contCenter clear">
				<div class="header-social col75">
				<?php if ( $socials ) : ?>
					<?php foreach( $socials as $social ) : ?>
						<div class="social-item">
							<a target="_blank" href="<?php echo esc_url( $social['link_url'] ); ?>">
								<i class="<?php echo esc_attr( $social['icon'] ); ?>"></i>
								<?php $replace = array( 'icon', '-', 'play', 'circled', 'squared' );  ?>
								<span><?php echo esc_html( str_replace( 'icon-', '', $social['icon'] ) ); ?></span>
							</a>
						</div>
					<?php endforeach; ?>
					<?php endif; ?>	
				</div>	

				<div class="header-additionals col25">
					<span><i class="icon-search"></i></span>
					<?php /* if ( class_exists( 'WooCommerce' ) ) : ?>
					<span class="header-cart"><i class="icon-shopping-bag"></i><?php phunk_woocommerce_cart_link(); ?><?php phunk_woocommerce_header_cart(); ?></span>
					<?php endif; */ ?>
				</div>
			</div>
		</div>

		<?php
	}
endif;

/**
 * Blog layout
 *
 */
function phunk_blog_layout() {

	$layout = get_theme_mod( 'blog_layout', 'layout-default' );

	return $layout;
}

/**
 * Single post layout
 *
 */
function phunk_single_layout() {

	$layout = get_theme_mod( 'post_layout', 'layout-default' );

	return $layout;
}

/**
 * Slider template
 */
function phunk_render_slider() {

	if ( !is_home() ) {
		return;
	}

	//Settings
	$ids 			= get_theme_mod( 'carousel_posts' );
	$autoplay_speed = get_theme_mod( 'autoplay_speed', '2000' );
	
	$args = array(
		'post__in' 		=> $ids,
		'post_status' 	=> 'publish'
	);
	$query = new WP_Query( $args );

	if ( $query->have_posts() ) { ?>
		<div class="hero-slider clear">

			<div class="slider-inner" data-slick='{"slidesToShow": 4, "adaptiveHeight": true, "arrows": false, "infinite": true, "autoplay": true, "autoplaySpeed": <?php echo absint( $autoplay_speed ) ?>}'>
				<?php
				while ( $query->have_posts() ) : $query->the_post(); ?>	

					<?php
						global $post;
						$image = get_the_post_thumbnail_url( $post, 'phunk-large' );
					?>

					<?php if ( has_post_thumbnail() ) : ?>	
						<div class="slide" style="background-image:url(<?php echo esc_url( $image ); ?> );">
							<div class="slide-content">
								<div class="content-inner">
									<?php phunk_first_category(); ?>
									<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
									<span class="entry-meta"><?php phunk_posted_on(); ?></span>
								</div>
							</div>
						</div>
					<?php endif; ?>
				<?php endwhile; ?>	
				</div>
		</div>

	<?php
	}
	
}

/**
 * Header image functio
 */
function phunk_header_image() {

	echo '<div id="site-hero" class="site-hero">';
		the_header_image_tag();
	echo '</div>';
}

/**
 * Modify the main query to exclude carousel posts from the loop
 */
function phunk_exclude_carousel_posts( $query ) {

	$exclude_posts 	= get_theme_mod( 'exclude_carousel_posts' );
	$carousel_posts = get_theme_mod( 'carousel_posts' );

	//Return if we don't need to exclude posts
	if ( !$exclude_posts ) {
		return;
	}
	
	//Exclude the posts
	if ( $query->is_home() && $query->is_main_query() && !is_admin() ) {
		$query->set( 'post__not_in', $carousel_posts );
	}
}
add_action( 'pre_get_posts', 'phunk_exclude_carousel_posts' );


/**
 * Remove labels from archive titles
 */
function phunk_remove_archive_labels( $title ) {
    if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = '<span class="vcard">' . get_the_author() . '</span>' ;
	}

	return $title;	
}
add_filter( 'get_the_archive_title', 'phunk_remove_archive_labels' );

/**
 * Same size tag cloud elements
 */
function phunk_tag_cloud_font_size( $args ) {
    $args['smallest'] 	= '13';
	$args['largest'] 	= '13';
	$args['unit']		= 'px';

    return $args;
}
add_filter('widget_tag_cloud_args', 'phunk_tag_cloud_font_size');

/**
 * Default theme colors
 */
if ( !function_exists( 'phunk_default_colors' ) ) :
	function phunk_default_colors() {

		$colors = array(
			'site_title_color' 					=> '#000',
			'site_description_color' 			=> '#707070',
			'top_bar_background_color'			=> '#000',
			'top_bar_color'						=> '#fff',
			'menu_items_color'					=> '#000',
			'submenu_items_color'				=> '#000',
			'submenu_background_color'			=> '#f7f7f7',
			'menu_bar_color'					=> '#fff',
			'accent_color'						=> '#ffc500',
			'body_text_color'					=> '#000',
			'widget_text_color'					=> '#757575',
			'widget_links_color'				=> '#000',
			'widget_title_background_color'		=> '#000',
			'widget_title_color'				=> '#fff',
			'footer_widgets_background_color'	=> '#000',
			'footer_widgets_color'				=> '#757575',
			'footer_widgets_title_color'		=> '#fff',
			'footer_widgets_links_color'		=> '#fff',
			'footer_credits_color'				=> '#d7d7d7',
			'footer_credits_background_color' 	=> '#000',
		);

		return $colors;

	}
endif;

/**
 * Search form
 */
function phunk_header_search_form() {
	?>
	<div class="header-search-form">
		<i class="icon-cancel"></i>
		<?php get_search_form(); ?>
	</div>
	<?php
}
add_action( 'phunk_before_page', 'phunk_header_search_form' );


/**
 * Subscribe footer section
 */
if ( !function_exists( 'phunk_subscribe_section' ) ) {
	function phunk_subscribe_section() {

		$shortcode = get_theme_mod( 'subscribe_shortcode' );

		if ( '' == $shortcode ) {
			return;
		}

		echo '<div class="subscribe-section">';
		echo 	'<div class="cont1600 contPad contCenter">';
		echo 		'<div class="inner-subscribe-section">';
		echo 			do_shortcode( wp_kses_post( $shortcode ) );
		echo 		'</div>';
		echo 	'</div>';
		echo '</div>';
	}
}

/**
 * Instagram footer section
 */
if ( !function_exists( 'phunk_instagram_section' ) ) {
	function phunk_instagram_section() {

		$shortcode = get_theme_mod( 'instagram_shortcode' );

		if ( '' === $shortcode ) {
			return;
		}

		echo '<div class="instagram-section">';
		echo 	do_shortcode( wp_kses_post( $shortcode ) );
		echo '</div>';
	}
}